=================
Managing projects
=================

Show all projects with ``tarbell list``
---------------------------------------

``tarbell list`` shows all projects in your Tarbell projects directory.

Switch to a project with ``tarbell switch <projectname>``
---------------------------------------------------------

You can be in any directory, but the project must be in your default Tarbell projects directory.

Run preview server with ``tarbell serve``
-----------------------------------------

You must be in a Tarbell project directory to run Tarbell serve.

Update a project's blueprint with ``tarbell update``
----------------------------------------------------

Run ``tarbell update`` to update a project's blueprint.

